"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const TreeView_1 = require("@mui/x-tree-view/TreeView");
const fast_deep_equal_1 = tslib_1.__importDefault(require("fast-deep-equal"));
const TreeItem_1 = require("@mui/x-tree-view/TreeItem");
const TreeItem_2 = tslib_1.__importDefault(require("./TreeItem"));
const LAZY_LOAD__PLACEHOLDER = "_lazy_load_placeholder";
const TreeView = ({ treeData, lazyLoadFn, treeItemClasses, titleRender, ContentComponent, expanded: expandedProp, onNodeToggle: onNodeToggleProp, defaultCollapseIcon, defaultExpandIcon, ...treeProps }) => {
    const [expanded, setExpanded] = (0, react_1.useState)(expandedProp ? [...expandedProp] : []);
    (0, react_1.useEffect)(() => {
        if (expandedProp) {
            if (!(0, fast_deep_equal_1.default)(expandedProp, expanded)) {
                setExpanded(expandedProp);
            }
        }
    }, [expandedProp]);
    const handleToggle = (event, nodeIds) => {
        setExpanded(nodeIds);
        onNodeToggleProp && onNodeToggleProp(null, nodeIds);
    };
    const handleExpand = (key) => {
        const newExpanded = [...expanded, key];
        setExpanded(newExpanded);
        onNodeToggleProp && onNodeToggleProp(null, newExpanded);
    };
    const renderChildren = (parent, children) => {
        const hasLazyLoad = typeof children != "undefined" && children.length == 0;
        if (hasLazyLoad && parent) {
            return ((0, jsx_runtime_1.jsx)(TreeItem_1.TreeItem, { nodeId: parent.key + LAZY_LOAD__PLACEHOLDER }));
        }
        if (!children) {
            return null;
        }
        return children.map((node) => {
            return ((0, jsx_runtime_1.jsx)(TreeItem_2.default, { node: node, collapseIcon: defaultCollapseIcon, expandIcon: defaultExpandIcon, ContentComponent: ContentComponent, treeItemClasses: treeItemClasses, onExpand: handleExpand, titleRender: titleRender, lazyLoadFn: lazyLoadFn, renderChildren: renderChildren }, node.key));
        });
    };
    return ((0, jsx_runtime_1.jsx)(TreeView_1.TreeView, { expanded: expanded, onNodeToggle: handleToggle, ...treeProps, children: treeData && renderChildren(null, treeData) }));
};
exports.default = TreeView;
